@@ -29,13 +29,14 @@
 
 class AdvancedPlotAssistant : public Cantor::Assistant
 {
+  Q_OBJECT
   public:
     AdvancedPlotAssistant( QObject* parent, QList<QVariant> args );
-    ~AdvancedPlotAssistant();
+    ~AdvancedPlotAssistant() override;
 
-    void initActions();
+    void initActions() Q_DECL_OVERRIDE;
 
-    QStringList run(QWidget* parentt);
+    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
 
 };
 
