@@ -59,7 +59,7 @@ class ImageEntry : public WorksheetEntry
     bool evaluate(WorksheetEntry::EvaluationOption evalOp = FocusNext) Q_DECL_OVERRIDE;
     void updateEntry() Q_DECL_OVERRIDE;
 
-    void populateMenu(QMenu *menu, const QPointF& pos) Q_DECL_OVERRIDE;
+    void populateMenu(QMenu* menu, QPointF pos) Q_DECL_OVERRIDE;
     void startConfigDialog();
     void setImageData(const QString& path, const ImageSize& displaySize,
                       const ImageSize& printSize, bool useDisplaySizeForPrinting);
