@@ -24,7 +24,7 @@
 #include <QTextCharFormat>
 #include <QPalette>
 #include <KColorScheme>
-#include <KLocale>
+#include <KLocalizedString>
 
 PageBreakEntry::PageBreakEntry(Worksheet* worksheet)
   : WorksheetEntry(worksheet)
@@ -55,7 +55,7 @@ int PageBreakEntry::type() const
     return Type;
 }
 
-void PageBreakEntry::populateMenu(QMenu *menu, const QPointF& pos)
+void PageBreakEntry::populateMenu(QMenu* menu, QPointF pos)
 {
     WorksheetEntry::populateMenu(menu, pos);
 }
